@@ -2,7 +2,7 @@ from __future__ import annotations
 
 # import pkg_resources
 
-import privateprefs.internal.data_serializer as ds
+import privateprefs.internal.data_serializer as _internal
 
 
 # _path_to_test_file = pkg_resources.resource_filename(__name__, 'data/prefs.txt')
@@ -14,7 +14,7 @@ def load(key: str) -> str | None:
     :param key: A lookup key
     :return: The stored value or None
     """
-    return ds.load(key)
+    return _internal.load(key)
     # dict_form_text_file = _load_dict_from_file()
     # if key in dict_form_text_file.keys():
     #     return dict_form_text_file[key]
@@ -28,7 +28,7 @@ def load_dict(keys: list = None) -> dict:
     :param keys: A list of Keys
     :return: A dict of key-value pairs
     """
-    return ds.load_dict(keys)
+    return _internal.load_dict(keys)
     # dict_form_text_file = _load_dict_from_file()
     # if keys is None:
     #     return dict_form_text_file
@@ -44,7 +44,7 @@ def delete_all() -> None:
     Deletes all stored key-value pairs.
     :return: None
     """
-    ds.delete_all()
+    _internal.delete_all()
     # _save_empty_file()
 
 
@@ -54,7 +54,7 @@ def delete(key: str) -> None:
     :param key: The key to delete the value of
     :return: None
     """
-    ds.delete(key)
+    _internal.delete(key)
     # loaded_dict = _load_dict_from_file()
     # loaded_dict.pop(key)
     # is_dict_empty = (loaded_dict == {})
